utils：例如相对路径查找、当前时间戳、时间格式处理、加密/解密、base64处理、url编码/解码、文件操作、压缩方法等
errors 模块，这个主要参考openai-proxy
log模块
常用的中间件，例如计算 API 请求时间、IP 白名单等、trace-id 添加
解析 stream 响应标准方式 + 返回 stream 的标准姿势

jwt auth接入用户中心

todo
最佳实践

